# Disable repacking of jars and requires/provides analysis since it takes hours for the
# tens of thousands of small jars
%global __jar_repack %{nil}
%global __requires_exclude_from ^.*\\.jar$
%global __provides_exclude_from ^.*\\.jar$

Name: eclipse-nls 
Summary: Babel language packs for the Eclipse platform and various plug-ins
License: EPL
URL: http://www.eclipse.org/babel/

Version: 4.6.0
Release: 1%{?dist}

# Babel language pack (zipped p2 update site) via: http://www.eclipse.org/babel/downloads.php
Source0: http://download.eclipse.org/technology/babel/update-site/R0.14.0/babel-R0.14.0-neon.zip

# This script extends the mvn_artifact script by allowing us generate reactor information
# for multiple artifacts at a time. There are so many jars (tens of thousands) that doing
# individual calls to mvn_artifact takes a large amount of time, this custom script does it
# in a fraction of the time by eliminating a bunch of process spawns and file ops per jar
Source1: generate.py

# Actually only needed for fp-p2 since there is no real maven build,
# we simply just want to install some maven artifacts
BuildRequires: tycho

BuildArch: noarch

%description
Babel language packs include translations for the Eclipse platform and other
Eclipse-related packages.

%files

# %1 subpackage id (ie Linux locale id)
# %2 Java locale id (mostly the same as Linux)
# %3 language name
%define lang_meta_pkg() \
%package %1 \
Summary: Eclipse/Babel language pack for %3 \
Requires: eclipse-filesystem \
Supplements: (eclipse-platform and langpacks-%1) \
\
%description %1 \
This language pack for %3 \
contains user-contributed translations of the \
strings in all Eclipse projects. Please see the http://babel.eclipse.org/ \
Babel project web pages for a full how-to-use explanation of these \
translations as well as how you can contribute to \
the translations of this and future versions of Eclipse. \
Note that English text will be displayed if Babel doesn't \
have a translation for a given string. \
\
%files %1 -f .mfiles-%2

%define spc() %(echo -n ' ')

%lang_meta_pkg ar ar Arabic
%lang_meta_pkg bg bg Bulgarian
%lang_meta_pkg ca ca Catalan
%lang_meta_pkg zh zh Chinese%{spc}(Simplified)
%lang_meta_pkg zh_TW zh_TW Chinese%{spc}(Traditional)
%lang_meta_pkg cs cs Czech
%lang_meta_pkg da da Danish
%lang_meta_pkg nl nl Dutch
%lang_meta_pkg en_AU en_AU English%{spc}(Australian)
%lang_meta_pkg en_CA en_CA English%{spc}(Canadian)
%lang_meta_pkg et et Estonian
%lang_meta_pkg eu eu Basque
%lang_meta_pkg fa fa Farsi
%lang_meta_pkg fi fi Finnish
%lang_meta_pkg fr fr French
%lang_meta_pkg de de German
%lang_meta_pkg el el Greek
# NB 'he' is 'iw' as far as Java is concerned.
# similarly, yi -> ji, id -> in
%lang_meta_pkg he iw Hebrew
%lang_meta_pkg hi hi Hindi
%lang_meta_pkg hu hu Hungarian
%lang_meta_pkg id id Indonesian
%lang_meta_pkg it it Italian
%lang_meta_pkg ja ja Japanese
%lang_meta_pkg ko ko Korean
%lang_meta_pkg ku ku Kurdish
%lang_meta_pkg lt lt Lithuanian
%lang_meta_pkg ml ml Malayalam
%lang_meta_pkg mn mn Mongolian
%lang_meta_pkg no no Norwegian
%lang_meta_pkg pl pl Polish
%lang_meta_pkg pt pt Portuguese
%lang_meta_pkg pt_BR pt_BR Portuguese%{spc}(Brazilian)
%lang_meta_pkg ro ro Romanian
%lang_meta_pkg ru ru Russian
%lang_meta_pkg es es Spanish
%lang_meta_pkg sk sk Slovak
%lang_meta_pkg sl sl Slovene
%lang_meta_pkg sq sq Albanian
%lang_meta_pkg sv sv Swedish
%lang_meta_pkg sr sr Serbian
%lang_meta_pkg th th Thai
%lang_meta_pkg tr tr Turkish
%lang_meta_pkg uk uk Ukrainian
%lang_meta_pkg en_AA en_AA Pseudo%{spc}Translations

%prep
%setup -q -n neon

cp -p %{SOURCE1} .

# Remove unused p2 metadata
rm -rf mirrors/ artifacts.jar content.jar

# "tl" should be Tagalog but is Klingon, which has < 1% coverage. Tagalog is unsupported.
# Remove unsupported langpacks
for nl in tl ; do
  rm features/*_${nl}_%{version}.v*.jar
  rm plugins/*.nl_${nl}_%{version}.v*.jar
done

%build
# Generate maven artifacts
for nl in ar bg ca zh zh_TW cs da nl en_AU en_CA et eu fa fi fr de el iw hi hu id it ja ko ku lt ml mn no pl pt pt_BR ro ru es sk sl sq sv sr th tr uk en_AA ; do
  python3 ./generate.py -Dtype=eclipse-feature "org.eclipse.nl_$nl::%{version}" $(find features -name *_${nl}_%{version}.v*.jar)
  python3 ./generate.py -Dtype=eclipse-plugin "org.eclipse.nl_$nl::%{version}" $(find plugins -name *.nl_${nl}_%{version}.v*.jar)
  %mvn_package "org.eclipse.nl_$nl:" $nl
done

%install
%mvn_install

%changelog
* Tue Oct 04 2016 Mat Booth <mat.booth@redhat.com> - 4.6.0-1
- Update to latest upstream release

* Thu Jul 14 2016 Mat Booth <mat.booth@redhat.com> - 4.5.0.v20151128060001-3
- Don't obsolete base package with every sub-package

* Mon Jul 11 2016 Mat Booth <mat.booth@redhat.com> - 4.5.0.v20151128060001-2
- Install translations as droplets, rhbz#1333480

* Tue Jul 5 2016 Alexander Kurtakov <akurtako@redhat.com> 4.5.0.v20151128060001-1
- Update to Babel 0.13.1.

* Tue Mar 01 2016 Parag Nemade <pnemade AT redhat DOT com> - 4.5.0.v20150804081228-3
- Add Supplements: for https://fedoraproject.org/wiki/Packaging:Langpacks guidelines

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.5.0.v20150804081228-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Aug 19 2015 akurtakov <akurtakov@localhost.localdomain> 4.5.0.v20150804081228-1
- Update to Mars release.

* Wed Jun 24 2015 Alexander Kurtakov <akurtako@redhat.com> 4.4.0.v20141223043836-1
- Update to latest Luna release.

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.4.0.v20140623020002-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jul 25 2014 Mat Booth <mat.booth@redhat.com> - 4.4.0.v20140623020002-1
- Update to latest upstream release (Luna)
- Add Basque/Lithuanian/Malayalam/Thai translations

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.0.v20121120043402-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.0.v20121120043402-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.0.v20121120043402-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 24 2013 Sean Flanigan <sflaniga@redhat.com> - 4.2.0.v20121120043402-1
- Updated from upstream to R0.10.1 (4.2.0.v20121120043402)

* Tue Sep 11 2012 Sean Flanigan <sflaniga@redhat.com> - 4.2.0.v20120721043402-2
- Switched to zipped p2 update site instead of using fetch-babel.sh

* Fri Sep 7 2012 Sean Flanigan <sflaniga@redhat.com> - 4.2.0.v20120721043402-1
- Updated from upstream to R0.10.0 (4.2.0.v20120721043402)

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.0.v20111128043401-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jul 10 2012 Alexander Kurtakov <akurtako@redhat.com> 3.7.0.v20111128043401-1
- Update to Indigo translations.

* Fri Feb  3 2012 Jens Petersen <petersen@redhat.com> - 3.6.0.v20100814043401-8
- add the epoch for the eclipse-platform requires

* Fri Feb  3 2012 Jens Petersen <petersen@redhat.com> - 3.6.0.v20100814043401-7
- keep fedora package noarch, but only build for eclipse archs for rhel
- clean away deprecated buildroot and defattr lines

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.6.0.v20100814043401-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.6.0.v20100814043401-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 10 2010 Sean Flanigan <sflaniga@redhat.com> - 3.6.0.v20100814043401-4
- Reverted unnecessary "fix" for Indonesian

* Fri Dec 10 2010 Sean Flanigan <sflaniga@redhat.com> - 3.6.0.v20100814043401-3
- Fixed locale mapping for Indonesian

* Mon Nov 29 2010 Sean Flanigan <sflaniga@redhat.com> - 3.6.0.v20100814043401-2
- Tweaked to make rpmlint happy

* Mon Nov 29 2010 Sean Flanigan <sflaniga@redhat.com> - 3.6.0.v20100814043401-1
- Updated from upstream to 0.8.0 (3.6.0.v20100814043401); added fa, removed en_CA

* Wed Aug 4 2010 Sean Flanigan <sflaniga@redhat.com> - 3.5.0.v20100729072834-1
- Updated from upstream to 0.8.0 RC1 (3.5.0.v20100731072648)

* Mon Aug 2 2010 Sean Flanigan <sflaniga@redhat.com> - 3.5.0.v20100729072834-1
- Updated from upstream; added locales ca, en_CA and id.

* Thu Jun 10 2010 Sean Flanigan <sflaniga@redhat.com> - 3.5.0.v20090620043401-3
- Marked eclipse-nls as not having debuginfo

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5.0.v20090620043401-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jul 13 2009 Sean Flanigan <sflaniga@redhat.com> - 3.5.0.v20090620043401-1
- Updated to Babel's release "0.7"
- Created a new fetch-babel.sh to automate the zip downloads

* Wed May 27 2009 Sean Flanigan <sflaniga@redhat.com> - 3.5.0.v20090423085802-1
- Updated from upstream; added Estonian.
- Fixed names/descriptions for languages with two word names such as "Portuguese (Brazilian)".
- Added Babel metadata files (artifact.jar and content.jar) to make P2 happier (presently disabled)
- Made the base package owner of dropins/babel and subdirectories

* Thu Apr 23 2009 Sean Flanigan <sflaniga@redhat.com> - 3.5.0.v20090417091040-1
- Updated to use Babel's zipped langpacks instead of fetch-babel.sh
- Changed versioning scheme to match changes in upstream versioning
- Updated to latest upstream langpacks for Eclipse 3.5 / Galileo

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.0-0.6.20080807snap
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Sep 11 2008 Sean Flanigan <sflaniga@redhat.com> - 0.2.0-0.5.20080807snap
- Applied another tidy-up patch from Jens Petersen and added a comment
 about the licence doc files

* Wed Sep 10 2008 Sean Flanigan <sflaniga@redhat.com> - 0.2.0-0.4.20080807snap
- Applied Jens Petersen's suggested patch to remove eclipse_version macro and 
  unnecessary buildroot checks

* Tue Sep 9 2008 Sean Flanigan <sflaniga@redhat.com> - 0.2.0-0.3.20080807snap
- Added eclipse_version macro
- Changed the Obsoletes version to be slightly higher than the last release of 
  eclipse-sdk-nls

* Mon Aug 11 2008 Sean Flanigan <sflaniga@redhat.com> - 0.2.0-0.2.20080807snap
- Fixed version in changelog
- Updated snapshot of Babel translation plugins
- Changed code for Hebrew to he (not iw); changed fetch-babel.sh to compensate
- Renamed eclipse_base macro to eclipse_data

* Fri Jul 25 2008 Sean Flanigan <sflaniga@redhat.com> - 0.2.0-0.1.20080720snap
- Initial rpm package
