import importlib.util
spec = importlib.util.spec_from_file_location("mvn_artifact", "/usr/share/java-utils/mvn_artifact.py")
mvn_artifact = importlib.util.module_from_spec(spec)
spec.loader.exec_module(mvn_artifact)

import sys
import os

def _main_main():
    parser = mvn_artifact.OptionParser()
    parser.add_option("-D", action="append", type="str",
                      help="add artifact property", metavar="property=value")

    sys.argv = mvn_artifact.args_to_unicode(sys.argv)

    (options, args) = parser.parse_args()

    coords = args.pop(0)
    jars = args

    if os.path.exists(mvn_artifact.config):
        metadata = mvn_artifact.Metadata.create_from_file(mvn_artifact.config)
    else:
        metadata = mvn_artifact.Metadata()

    for jar_path in jars:
        uart = mvn_artifact.Artifact.from_mvn_str(coords)
        uart.validate(allow_backref=False)
        if not (uart.groupId and uart.version):
            parser.error("Defined artifact has to include at least groupId, and version")

        artifactId = os.path.basename(jar_path[0:jar_path.rfind('_')])
        art = mvn_artifact.MetadataArtifact(uart.groupId, artifactId, version=uart.version)
        if hasattr(uart, "extension") and uart.extension:
            art.extension = uart.extension
        if hasattr(uart, "classifier") and uart.classifier:
            art.classifier = uart.classifier
        extension = (os.path.splitext(jar_path)[1])[1:]
        if hasattr(art, "extension") and art.extension and art.extension != extension:
            raise mvn_artifact.ExtensionsDontMatch("Extensions don't match: '%s' != '%s'" % (art.extension, extension))
        else:
            art.extension = extension

        art.properties["xmvn.resolver.disableEffectivePom"] = "true"

        if options.D:
            for d_opt in options.D:
                key, value = d_opt.split("=")
                art.properties[key] = value

        mvn_artifact.add_artifact_elements(metadata, art, None, jar_path)

    metadata.write_to_file(mvn_artifact.config)

if __name__ == "__main__":
    try:
        _main_main()
    except mvn_artifact.JavaPackagesToolsException as e:
        sys.exit(e)
